@@ -1,13 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Pheanstalk\Exception;
 
 use Pheanstalk\Exception;
 
 /**
  * An exception originating as a beanstalkd server error.
- *
- * @author  Paul Annesley
+ * @extensible
  */
 class ServerException extends Exception
 {
